@@ -49,14 +49,30 @@ class Axes:
         xlabel = obj.get_xlabel()
         if xlabel:
             xlabel = _common_texification(xlabel)
-            self.axis_options.append(f"xlabel={{{xlabel}}}")
+
+            labelcolor = obj.xaxis.label.get_c()
+
+            if labelcolor != "black":
+                data, col, _ = _color.mpl_color2xcolor(data, labelcolor)
+                self.axis_options.append(f"xlabel=\\textcolor{{{col}}}{{{xlabel}}}")
+            else:
+                self.axis_options.append(f"xlabel={{{xlabel}}}")
+
             xrotation = obj.xaxis.get_label().get_rotation()
             if xrotation != 0:
                 self.axis_options.append(f"xlabel style={{rotate={xrotation - 90}}}")
+
         ylabel = obj.get_ylabel()
         if ylabel:
             ylabel = _common_texification(ylabel)
-            self.axis_options.append(f"ylabel={{{ylabel}}}")
+
+            labelcolor = obj.yaxis.label.get_c()
+            if labelcolor != "black":
+                data, col, _ = _color.mpl_color2xcolor(data, labelcolor)
+                self.axis_options.append(f"ylabel=\\textcolor{{{col}}}{{{ylabel}}}")
+            else:
+                self.axis_options.append(f"ylabel={{{ylabel}}}")
+
             yrotation = obj.yaxis.get_label().get_rotation()
             if yrotation != 90:
                 self.axis_options.append(f"ylabel style={{rotate={yrotation - 90}}}")
@@ -525,6 +541,7 @@ def _get_tick_position(obj, axes_obj):
     if len(set(major_ticks_top)) == 1 and major_ticks_top[0] is True:
         major_ticks_top_show_all = True
 
+    position_string = None
     major_ticks_position = None
     if not major_ticks_bottom_show_all and not major_ticks_top_show_all:
         position_string = f"{axes_obj}majorticks=false"
@@ -546,27 +563,39 @@ def _get_ticks(data, xy, ticks, ticklabels):
     necessary axis options for the given configuration.
     """
     axis_options = []
-    pgfplots_ticks = []
-    pgfplots_ticklabels = []
+
+    # Check if the label is necessary. If one of the labels is, then all of them must
+    # appear in the TikZ plot.
     is_label_required = False
     for tick, ticklabel in zip(ticks, ticklabels):
         # store the label anyway
         label = ticklabel.get_text()
+
+        if not ticklabel.get_visible():
+            is_label_required = True
+            break
+
+        if not label:
+            continue
+
+        try:
+            label_float = float(label.replace("\N{MINUS SIGN}", "-"))
+        except ValueError:
+            is_label_required = True
+            break
+        else:
+            if abs(label_float - tick) > 1.0e-10 + 1.0e-10 * abs(tick):
+                is_label_required = True
+                break
+
+    pgfplots_ticks = []
+    pgfplots_ticklabels = []
+    for tick, ticklabel in zip(ticks, ticklabels):
+        label = ticklabel.get_text()
         if "," in label:
             label = "{" + label + "}"
-        if ticklabel.get_visible():
-            label = _common_texification(label)
-            pgfplots_ticklabels.append(label)
-        else:
-            is_label_required = True
-        # Check if the label is necessary. If one of the labels is, then all of them
-        # must appear in the TikZ plot.
-        if label:
-            try:
-                label_float = float(label.replace("\N{MINUS SIGN}", "-"))
-                is_label_required = is_label_required or (label and label_float != tick)
-            except ValueError:
-                is_label_required = True
+        pgfplots_ticklabels.append(_common_texification(label))
+
     # note: ticks may be present even if labels are not, keep them for grid lines
     for tick in ticks:
         pgfplots_ticks.append(tick)
@@ -601,13 +630,19 @@ def _get_ticks(data, xy, ticks, ticklabels):
 
 def _is_colorbar_heuristic(obj):
     """Find out if the object is in fact a color bar."""
-    # TODO come up with something more accurate here
+    # Not sure if these properties are always present
+    if hasattr(obj, "_colorbar") or hasattr(obj, "_colorbar_info"):
+        return True
+
+    # TODO come up with something more accurate here. See
+    # <https://discourse.matplotlib.org/t/find-out-if-an-axes-object-is-a-colorbar/22563>
     # Might help:
     # TODO Are the colorbars exactly the l.collections.PolyCollection's?
+
     try:
         aspect = float(obj.get_aspect())
     except ValueError:
-        # e.g., aspect == 'equal'
+        # e.g., aspect in ['equal', 'auto']
         return False
 
     # Assume that something is a colorbar if and only if the ratio is above 5.0
@@ -617,10 +652,10 @@ def _is_colorbar_heuristic(obj):
     #
     #    plt.colorbar(im, aspect=5)
     #
-    limit_ratio = 5.0
+    threshold_ratio = 5.0
 
-    return (aspect >= limit_ratio and len(obj.get_xticks()) == 0) or (
-        aspect <= 1.0 / limit_ratio and len(obj.get_yticks()) == 0
+    return (aspect >= threshold_ratio and len(obj.get_xticks()) == 0) or (
+        aspect <= 1.0 / threshold_ratio and len(obj.get_yticks()) == 0
     )
 
 
@@ -801,7 +836,7 @@ def _gcd_array(X):
 
 def _gcd(a, b):
     """Euclidean algorithm for calculating the GCD of two numbers a, b.
-    This algoritm also works for real numbers:
+    This algorithm also works for real numbers:
     Find the greatest number h such that a and b are integer multiples of h.
     """
     # Keep the tolerance somewhat significantly above machine precision as otherwise
